summaryrefslogtreecommitdiff
path: root/framework/Web/UI/WebControls/TDataBoundControl.php
diff options
context:
space:
mode:
Diffstat (limited to 'framework/Web/UI/WebControls/TDataBoundControl.php')
-rw-r--r--framework/Web/UI/WebControls/TDataBoundControl.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/framework/Web/UI/WebControls/TDataBoundControl.php b/framework/Web/UI/WebControls/TDataBoundControl.php
index 9e6ecbf3..09023b66 100644
--- a/framework/Web/UI/WebControls/TDataBoundControl.php
+++ b/framework/Web/UI/WebControls/TDataBoundControl.php
@@ -128,7 +128,7 @@ abstract class TDataBoundControl extends TWebControl
}
/**
- * @return boolean if databind has been invoked in the previous page request
+ * @return boolean whether databind has been invoked in the previous page request
*/
protected function getIsDataBound()
{
@@ -272,7 +272,7 @@ abstract class TDataBoundControl extends TWebControl
}
/**
* Sets page's <b>OnPreLoad</b> event handler as {@link onPagePreLoad}.
* If viewstate is disabled and the current request is a postback,
* {@link setRequiresDataBinding RequiresDataBinding} will be set true.
* This method overrides the parent implementation.
@@ -282,7 +282,7 @@ abstract class TDataBoundControl extends TWebControl
{
parent::onInit($param);
$page=$this->getPage();
- $page->attachEventHandler('OnPreLoad',array($this,'onPagePreLoad'));
+ $page->attachEventHandler('OnPreLoad',array($this,'pagePreLoad'));
}
/**
@@ -291,7 +291,7 @@ abstract class TDataBoundControl extends TWebControl
* @param mixed event sender
* @param TEventParameter event parameter
*/
- public function onPagePreLoad($sender,$param)
+ public function pagePreLoad($sender,$param)
{
$this->_initialized=true;
$isPostBack=$this->getPage()->getIsPostBack();
@@ -272,7 +272,7 @@ abstract class TDataBoundControl extends TWebControl
}
/**
- * Sets page's <b>OnPreLoad</b> event handler as {@link onPagePreLoad}.
+ * Sets page's <b>OnPreLoad</b> event handler as {@link pagePreLoad}.
* If viewstate is disabled and the current request is a postback,
* {@link setRequiresDataBinding RequiresDataBinding} will be set true.